/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.ca.internal;

import org.diirt.datasource.CompositeDataSource;
import org.diirt.datasource.DataSource;
import org.diirt.datasource.PVManager;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

import com.aquenos.epics.jackie.diirt.datasource.ca.CaDataSourceProvider;

/**
 * Activator for the <code>com.aquenos.epics.jackie.diirt.datasource.ca</code>
 * bundle. This activator forces the installation of the
 * {@link CaDataSourceProvider} in the {@link PVManager}'s default data-source.
 * This means that this provider is going to be used for channels specifying the
 * "ca" provider, even if the JCA-based data-source provider is also present.
 * 
 * @author Sebastian Marsching
 */
public class Activator implements BundleActivator {

    @Override
    public void start(BundleContext context) throws Exception {
        // When the default data-source is a composite data-source, we replace
        // the default "ca" provider with our provider.
        DataSource defaultDataSource = PVManager.getDefaultDataSource();
        if (defaultDataSource instanceof CompositeDataSource) {
            CaDataSourceProvider
                    .registerWith((CompositeDataSource) defaultDataSource);
        }
    }

    @Override
    public void stop(BundleContext context) throws Exception {
        // It would be optimal if we unregistered the data-source provider when
        // this bundle is stopped, but the CompositeDataSource does not offer a
        // method for this yet.
    }

}
