/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VInt;

import com.aquenos.epics.jackie.common.value.ChannelAccessControlsLong;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeLong;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVInt;

/**
 * Type adapter that convert from {@link ChannelAccessControlsLong} and
 * {@link ChannelAccessTimeLong} to {@link VInt}. This adapter can only be used
 * if the value has exactly one element.
 * 
 * @author Sebastian Marsching
 */
public class ScalarLongTypeAdapter extends JackieDataSourceTypeAdapter<VInt> {

    /**
     * Single instance of this adapter.
     */
    public static final ScalarLongTypeAdapter INSTANCE = new ScalarLongTypeAdapter();

    private ScalarLongTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_LONG, VInt.class);
    }

    @Override
    protected VInt convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_LONG and we thus know that the
        // monitors return a DBR_CTRL_LONG and DBR_TIME_LONG.
        ChannelAccessControlsLong controlsValue = (ChannelAccessControlsLong) message
                .getControlsValue();
        ChannelAccessTimeLong timeValue = (ChannelAccessTimeLong) message
                .getTimeValue();
        return new JackieVInt(controlsValue, timeValue,
                connection.getDisconnectTime());
    }

}
