/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VString;

import com.aquenos.epics.jackie.common.value.ChannelAccessTimeString;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVString;

/**
 * Type adapter that convert from {@link ChannelAccessTimeString} to
 * {@link VString}. This adapter can only be used if the value has exactly one
 * element.
 * 
 * @author Sebastian Marsching
 */
public class ScalarStringTypeAdapter
        extends JackieDataSourceTypeAdapter<VString> {

    /**
     * Single instance of this adapter.
     */
    public static final ScalarStringTypeAdapter INSTANCE = new ScalarStringTypeAdapter();

    private ScalarStringTypeAdapter() {
        super(false, ChannelAccessValueType.DBR_STRING, VString.class);
    }

    @Override
    protected VString convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_STRING and we thus know that the
        // monitor returns a DBR_TIME_STRING.
        ChannelAccessTimeString timeValue = (ChannelAccessTimeString) message
                .getTimeValue();
        return new JackieVString(timeValue, connection.getDisconnectTime());
    }

}
