/*
 * Copyright 2017-2018 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.vtype;

import java.time.Instant;
import java.util.List;

import org.diirt.util.array.ArrayInt;
import org.diirt.util.array.ListInt;
import org.diirt.vtype.VStringArray;
import org.diirt.vtype.VTypeToString;

import com.aquenos.epics.jackie.common.value.ChannelAccessTimeString;

/**
 * {@link VStringArray} implementation that is backed by a
 * {@link ChannelAccessTimeString}.
 * 
 * @author Sebastian Marsching
 */
public final class JackieVStringArray extends
        JackieAlarmAndTime<ChannelAccessTimeString> implements VStringArray {

    /**
     * <p>
     * Creates a value backed by the specified {@code value}. The {@code value}
     * is used for the alarm status, time-stamp, and value.
     * </p>
     * 
     * <p>
     * If {@code disconnectTime} is not <code>null</code>, it is used as the
     * time-stamp and the alarm severity is set to {@code UNDEFINED}.
     * </p>
     * 
     * @param value
     *            value used for alarm status, time-stamp, and value.
     * @param disconnectTime
     *            time at which the channel was disconnected. Usually this
     *            should be <code>null</code>. If it is not <code>null</code>,
     *            the alarm severity is set to {@code UNDEFINED} and this
     *            parameter is used as the time-stamp (instead of using the
     *            time-stamp from the {@code timeValue}.
     */
    public JackieVStringArray(ChannelAccessTimeString value,
            Instant disconnectTime) {
        super(value, disconnectTime, false);
    }

    @Override
    public List<String> getData() {
        return timeValue.getValue();
    }

    @Override
    public ListInt getSizes() {
        return new ArrayInt(timeValue.getValueSize());
    }

    @Override
    public String toString() {
        return VTypeToString.toString(this);
    }

}
